==> pointpos_api-0.0.16.tar.gz: test/employee_api_test.dart <==
import 'package:pointpos_api/api.dart';
import 'package:test/test.dart';


/// tests for EmployeeApi
void main() {
  var instance = new EmployeeApi();

  group('tests for EmployeeApi', () {
    // Create Employee
    //
    // Create Employee
    //
    //Future<Employee> createEmployee(String authorization, String xAPIKey, Employee body, { String xPin }) async 
    test('test createEmployee', () async {
      // TODO
    });

    // Delete Employee By ID
    //
    // Delete Employee By ID
    //
    //Future deleteEmployeeByID(String authorization, String xAPIKey, String id, { String xPin }) async 
    test('test deleteEmployeeByID', () async {
      // TODO
    });

    // Get Employee List
    //
    // Get Employee  List
    //
    //Future<List<Employee>> findEmployee(String authorization, String xAPIKey, { String xPin, num limit, num offset, String sort, String direction, List<String> filter }) async 
    test('test findEmployee', () async {
      // TODO
    });

    // Get Employee By ID
    //
    // Get Employee By ID
    //
    //Future<Employee> getEmployeeByID(String authorization, String xAPIKey, String id, { String xPin }) async 
    test('test getEmployeeByID', () async {
      // TODO
    });

    // Update Employee By ID
    //
    // Update [object Object] By ID
    //
    //Future<Employee> updateEmployeeByID(String authorization, String xAPIKey, String id, Employee body, { String xPin }) async 
    test('test updateEmployeeByID', () async {
      // TODO
    });

  });
}

==> pointpos_api-0.2.1.tar.gz: test/employee_api_test.dart <==
import 'package:pointpos_api/api.dart';
import 'package:test/test.dart';


/// tests for EmployeeApi
void main() {
  var instance = new EmployeeApi();

  group('tests for EmployeeApi', () {
    // Create Employee
    //
    // Create Employee
    //
    //Future<Employee> createEmployee(String authorization, String xAPIKey, Employee body, { String xPin }) async 
    test('test createEmployee', () async {
      // TODO
    });

    // Delete Employee By ID
    //
    // Delete Employee By ID
    //
    //Future deleteEmployeeByID(String authorization, String xAPIKey, String id, { String xPin }) async 
    test('test deleteEmployeeByID', () async {
      // TODO
    });

    // Get Employee List
    //
    // Get Employee  List
    //
    //Future<List<Employee>> findEmployee(String authorization, String xAPIKey, { String xPin, num limit, num offset, String sort, String direction, List<String> filter, bool withDeleted }) async 
    test('test findEmployee', () async {
      // TODO
    });

    // Get Employee By ID
    //
    // Get Employee By ID
    //
    //Future<Employee> getEmployeeByID(String authorization, String xAPIKey, String id, { String xPin }) async 
    test('test getEmployeeByID', () async {
      // TODO
    });

    // Update Employee By ID
    //
    // Update [object Object] By ID
    //
    //Future<Employee> updateEmployeeByID(String authorization, String xAPIKey, String id, Employee body, { String xPin }) async 
    test('test updateEmployeeByID', () async {
      // TODO
    });

  });
}
